summary.elect: Summarises the estimation of the life expectancies

View source: R/summary.elect.r

summary.electR Documentation

Summarises the estimation of the life expectancies

Description

Summary of estimated state-specific and marginal life expectancies

Usage

## S3 method for class 'elect'
summary(object, probs = c(0.025, 0.5, 0.975),
               digits = 3, StartStateTotals = FALSE,
               print = TRUE, sd.model = FALSE,...)

Arguments

object

Life expectancies estimated by elect

probs

Numeric vector of probabilities with values in [0,1] for quantiles

digits

Number of decimal places in output

StartStateTotals

TRUE for output on start-state totals (for S>0 in elect)

print

TRUE for printing output to screen, FALSE otherwise

sd.model

TRUE for printing a summary of the fitted model for the prevalence

...

Other arguments (not yet implemented)

Details

A summary for the state-specific and marginal life expectancies as derived in elect. Quantiles are derived from simulation based on the maximum likelihood estimation.

Author(s)

Ardo van den Hout

See Also

elect, plusmin, plot.elect


elect documentation built on July 22, 2026, 5:13 p.m.

Related to summary.elect in elect...