View source: R/summary.elect.r
| summary.elect | R Documentation |
Summary of estimated state-specific and marginal life expectancies
## S3 method for class 'elect'
summary(object, probs = c(0.025, 0.5, 0.975),
digits = 3, StartStateTotals = FALSE,
print = TRUE, sd.model = FALSE,...)
object |
Life expectancies estimated by |
probs |
Numeric vector of probabilities with values in [0,1] for quantiles |
digits |
Number of decimal places in output |
StartStateTotals |
TRUE for output on start-state totals (for |
print |
TRUE for printing output to screen, FALSE otherwise |
sd.model |
TRUE for printing a summary of the fitted model for the prevalence |
... |
Other arguments (not yet implemented) |
A summary for the state-specific and marginal life expectancies as derived in
elect. Quantiles are derived from simulation based on the maximum likelihood estimation.
Ardo van den Hout
elect, plusmin, plot.elect
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.